==> react-atom-textarea-2.12.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomTextarea';
var SIZES = {
  SHORT: 'short',
  LONG: 'long'
};
var TEXTAREA_STATES = {
  ERROR: 'error',
  SUCCESS: 'success',
  ALERT: 'alert'
};
var DEFAULT_PROPS = {
  size: SIZES.SHORT,
  onChange: function onChange() {},
  onBlur: function onBlur() {}
};

var AtomTextarea = function AtomTextarea(_ref) {
  var _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? DEFAULT_PROPS.onChange : _ref$onChange,
      _ref$onBlur = _ref.onBlur,
      onBlur = _ref$onBlur === void 0 ? DEFAULT_PROPS.onBlur : _ref$onBlur,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? DEFAULT_PROPS.size : _ref$size,
      value = _ref.value,
      errorState = _ref.errorState,
      state = _ref.state,
      props = _objectWithoutPropertiesLoose(_ref, ["onChange", "onBlur", "size", "value", "errorState", "state"]);

  var className = cx(BASE_CLASS, BASE_CLASS + "--" + size, errorState && BASE_CLASS + "--" + TEXTAREA_STATES.ERROR, errorState === false && BASE_CLASS + "--" + TEXTAREA_STATES.SUCCESS, state && BASE_CLASS + "--" + state);

  var handleChange = function handleChange(ev) {
    var _ev$target = ev.target,
        value = _ev$target.value,
        name = _ev$target.name;
    onChange(ev, {
      value: value,
      name: name
    });
  };

  return /*#__PURE__*/React.createElement("textarea", Object.assign({}, props, {
    onBlur: onBlur,
    onChange: handleChange,
    className: className,
    value: value
  }));
};

AtomTextarea.displayName = 'AtomTextarea';
export default AtomTextarea;
export { SIZES as AtomTextareaSizes, TEXTAREA_STATES as AtomTextareaStates };

==> react-atom-textarea-2.13.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import React from 'react';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomTextarea';
var SIZES = {
  SHORT: 'short',
  LONG: 'long'
};
var TEXTAREA_STATES = {
  ERROR: 'error',
  SUCCESS: 'success',
  ALERT: 'alert'
};
var DEFAULT_PROPS = {
  size: SIZES.SHORT,
  onChange: function onChange() {},
  onBlur: function onBlur() {}
};

var AtomTextarea = function AtomTextarea(_ref) {
  var _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? DEFAULT_PROPS.onChange : _ref$onChange,
      _ref$onBlur = _ref.onBlur,
      onBlur = _ref$onBlur === void 0 ? DEFAULT_PROPS.onBlur : _ref$onBlur,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? DEFAULT_PROPS.size : _ref$size,
      value = _ref.value,
      errorState = _ref.errorState,
      state = _ref.state,
      props = _objectWithoutPropertiesLoose(_ref, ["onChange", "onBlur", "size", "value", "errorState", "state"]);

  var className = cx(BASE_CLASS, BASE_CLASS + "--" + size, errorState && BASE_CLASS + "--" + TEXTAREA_STATES.ERROR, errorState === false && BASE_CLASS + "--" + TEXTAREA_STATES.SUCCESS, state && BASE_CLASS + "--" + state);

  var handleChange = function handleChange(ev) {
    var _ev$target = ev.target,
        value = _ev$target.value,
        name = _ev$target.name;
    onChange(ev, {
      value: value,
      name: name
    });
  };

  return /*#__PURE__*/_jsx("textarea", _extends({}, props, {
    onBlur: onBlur,
    onChange: handleChange,
    className: className,
    value: value
  }));
};

AtomTextarea.displayName = 'AtomTextarea';
export default AtomTextarea;
export { SIZES as AtomTextareaSizes, TEXTAREA_STATES as AtomTextareaStates };
